@@ -1,12 +1,16 @@
 
+from abc import ABC, abstractmethod
+
 from shorttext.utils.classification_exceptions import NotImplementedException
 
-class SpellCorrector:
+
+class SpellCorrector(ABC):
     """ Base class for all spell corrector.
 
-    This class is not implemented; this can be seen as an "abstract class."
+    This class is not implemented; this is an "abstract class."
 
     """
+    @abstractmethod
     def train(self, text):
         """ Train the spell corrector with the given corpus.
 
@@ -15,6 +19,7 @@ class SpellCorrector:
         """
         raise NotImplementedException()
 
+    @abstractmethod
     def correct(self, word):
         """ Recommend a spell correction to given the word.
 
@@ -23,4 +28,4 @@ class SpellCorrector:
         :type word: str
         :rtype: str
         """
-        return word
\ No newline at end of file
+        return word
